### django-spiff-workflow
Integration of Python [`spiffworkflow`](https://github.com/sartography/SpiffWorkflow) library with Django

### Installation

Install `django-spiff-workflow` using `pip install django-spiff-workflow`

Add `"django_spiff_workflow"` to your `INSTALLED_APPS` settings like this:

```
INSTALLED_APPS = (
    "django_spiff_workflow",
    ...
)
```

### More documentation

For more information check the documentation of [`spiff-workflow` doc](https://spiffworkflow.readthedocs.io/en/latest/index.html).